<template>
  <a-modal
    :title='title'
    :width="650"
    :visible='visible'
    :maskClosable='false'
    cancelText='关闭'
    @cancel='handleCancel'
    :confirmLoading='confirmLoading'
  >
    <!-- @ok='handleOk' -->
    <a-spin :spinning='confirmLoading'>
      <a-form :form="form">
        <a-row>
          <a-col :span='24'>
            <a-form-item
              label='请购单号'
              :labelCol='labelCol'
              :wrapperCol='wrapperCol'
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入请购单号'"
                v-decorator="['num', validatorRules.num ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span='24'>
            <a-form-item
              label="审核意见"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-textarea
                rows='3'
                placeholder='请输入审核意见'
                v-decorator="['approvalOpinions', validatorRules.approvalOpinions ]"
              ></a-textarea>
            </a-form-item>
          </a-col>

        </a-row>
      </a-form>
    </a-spin>
    <template slot='footer'>
      <a-popconfirm
        @confirm="() => handleReject()"
        title="确认将当前备件请购单驳回？"
      >
        <a-button
          :loading='confirmLoading'
          :style="{marginRight: '8px'}"
        >
          驳回
        </a-button>
      </a-popconfirm>
      <a-popconfirm
        @confirm="() => handleOk()"
        title="确认将当前备件请购单审核通过？"
      >
        <a-button
          type='primary'
          :loading='confirmLoading'
          :style="{marginRight: '8px'}"
        >
          通过
        </a-button>
      </a-popconfirm>
    </template>
  </a-modal>

</template>

<script>
import { httpAction, requestPut, postAction } from '@/api/manage'
import Tooltip from 'ant-design-vue/es/tooltip'
import pick from 'lodash.pick'

export default {
  name: 'AuditApprovalModal',
  components: {
    Tooltip
  },
  data() {
    return {
      title: '操作',
      visible: false,
      disableSubmit: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        approvalOpinions: {
          rules: [
            { required: true, message: '请输入审核意见!' },
          ]
        },
      },
      url: {
        auditApproval: "/spare/sparePartRequirement/auditApproval",
      },
    }
  },


  methods: {
    close() {
      this.$emit('close')
      this.visible = false
    },

    handleCancel() {
      this.close()
    },
    showModals(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'num'));
        this.form.setFieldsValue({ approvalOpinions: "" });
      }, 200);
    },

    handleReject() {
      const that = this;
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          if (this.model.auditStatus == '1') {
            formData.auditStatus = '3'
          }
          requestPut(this.url.auditApproval, formData, { id: this.model.id }).then((res) => {
            if (res.success) {
              that.$message.success("驳回成功！");
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },


    handleOk() {
      const that = this;
      that.form.validateFields((err, values) => {
        if (!err) {
          this.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          if (this.model.auditStatus == '1') {
            formData.auditStatus = '4'
          }
          requestPut(this.url.auditApproval, formData, { id: this.model.id }).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },
  }

}
</script>

<style lang='less' scoped>
/deep/ .frozenRowClass {
  color: #c9c9c9;
}

.fontweight {
  font-weight: bold;
}

.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}

/deep/ .ant-modal-title {
  text-align: center;
}
</style>